@@ -1,12 +1,20 @@
 package IO_Dumper;
 use strict;
-use IO::All '-Base';
+use warnings;
+use IO::All -base;
+
+our @EXPORT = 'io';
+
+sub io { return IO_Dumper->new(@_) };
 
 package IO::All::Filesys;
 use Data::Dumper;
 sub dump {
+    my $self = shift;
     local $Data::Dumper::Indent = 1;
     local $Data::Dumper::Sortkeys = 1;
     $self->print(Data::Dumper::Dumper(@_));
     return $self;
-} 
+}
+
+1;
